summaryrefslogtreecommitdiffstats
path: root/kommander/editor/actiondnd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kommander/editor/actiondnd.cpp')
-rw-r--r--kommander/editor/actiondnd.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kommander/editor/actiondnd.cpp b/kommander/editor/actiondnd.cpp
index 3fc26240..3910b4cf 100644
--- a/kommander/editor/actiondnd.cpp
+++ b/kommander/editor/actiondnd.cpp
@@ -294,7 +294,7 @@ void QDesignerToolBar::contextMenuEvent( TQContextMenuEvent *e )
menu.insertItem( i18n("Delete Toolbar" ), 1 );
int res = menu.exec( e->globalPos() );
if ( res != -1 ) {
- RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n("Delete Toolbar '%1'" ).tqarg( name() ),
+ RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n("Delete Toolbar '%1'" ).arg( name() ),
formWindow, 0, this );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -360,7 +360,7 @@ void QDesignerToolBar::buttonContextMenuEvent( TQContextMenuEvent *e, TQObject *
int index = actionList.find( a );
RemoveActionFromToolBarCommand *cmd = new RemoveActionFromToolBarCommand(
i18n("Delete Action '%1' From Toolbar '%2'" ).
- tqarg( a->name() ).tqarg( caption() ),
+ arg( a->name() ).arg( caption() ),
formWindow, a, this, index );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -380,7 +380,7 @@ void QDesignerToolBar::buttonContextMenuEvent( TQContextMenuEvent *e, TQObject *
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
} else if ( res == ID_DELTOOLBAR ) {
- RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n("Delete Toolbar '%1'" ).tqarg( name() ),
+ RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n("Delete Toolbar '%1'" ).arg( name() ),
formWindow, 0, this );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -420,7 +420,7 @@ void QDesignerToolBar::removeWidget( TQWidget *w )
int index = actionList.find( a );
RemoveActionFromToolBarCommand *cmd =
new RemoveActionFromToolBarCommand( i18n("Delete Action '%1' From Toolbar '%2'" ).
- tqarg( a->name() ).tqarg( caption() ),
+ arg( a->name() ).arg( caption() ),
formWindow, a, this, index );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -443,7 +443,7 @@ void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
int index = actionList.find( a );
RemoveActionFromToolBarCommand *cmd =
new RemoveActionFromToolBarCommand( i18n("Delete Action '%1' From Toolbar '%2'" ).
- tqarg( a->name() ).tqarg( caption() ),
+ arg( a->name() ).arg( caption() ),
formWindow, a, this, index );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -462,7 +462,7 @@ void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
}
if ( !drag->drag() ) {
AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n("Add Action '%1' to Toolbar '%2'" ).
- tqarg( a->name() ).tqarg( caption() ),
+ arg( a->name() ).arg( caption() ),
formWindow, a, this, index );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -543,7 +543,7 @@ void QDesignerToolBar::dropEvent( TQDropEvent *e )
}
AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n("Add Action '%1' to Toolbar '%2'" ).
- tqarg( a->name() ).tqarg( caption() ),
+ arg( a->name() ).arg( caption() ),
formWindow, a, this, index );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -671,7 +671,7 @@ void QDesignerToolBar::doInsertWidget( const TQPoint &p )
if ( !insertAnchor )
index = 0;
AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n("Add Widget '%1' to Toolbar '%2'" ).
- tqarg( w->name() ).tqarg( caption() ),
+ arg( w->name() ).arg( caption() ),
formWindow, a, this, index );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -739,15 +739,15 @@ void QDesignerMenuBar::contextMenuEvent( TQContextMenuEvent *e )
int res = menu.exec( e->globalPos() );
if ( res == 1 ) {
TQMenuItem *item = findItem( idAt( itm ) );
- RemoveMenuCommand *cmd = new RemoveMenuCommand( i18n("Delete Menu '%1'" ).tqarg( item->text() ),
+ RemoveMenuCommand *cmd = new RemoveMenuCommand( i18n("Delete Menu '%1'" ).arg( item->text() ),
formWindow,
(TQMainWindow*)parentWidget(), this,
(QDesignerPopupMenu*)item->popup(),
idAt( itm ), itm, item->text() );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
- // #### need to do a proper tqinvalidate and re-tqlayout
- parentWidget()->tqlayout()->tqinvalidate();
+ // #### need to do a proper invalidate and re-tqlayout
+ parentWidget()->tqlayout()->invalidate();
parentWidget()->tqlayout()->activate();
} else if ( res == 2 ) {
bool ok;
@@ -756,7 +756,7 @@ void QDesignerMenuBar::contextMenuEvent( TQContextMenuEvent *e )
text( idAt( itm ) ), &ok, 0 );
if ( ok ) {
RenameMenuCommand *cmd = new RenameMenuCommand(
- i18n("Rename Menu '%1' to '%2'" ).tqarg( old ).tqarg( txt ),
+ i18n("Rename Menu '%1' to '%2'" ).arg( old ).arg( txt ),
formWindow, this, idAt( itm ), old, txt );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -880,7 +880,7 @@ void QDesignerMenuBar::dropEvent( TQDropEvent *e )
TQString txt = s2;
insertItem( txt, popup, -1, insertAt );
- MoveMenuCommand *cmd = new MoveMenuCommand( i18n("Move Menu '%1'" ).tqarg( txt ), formWindow,
+ MoveMenuCommand *cmd = new MoveMenuCommand( i18n("Move Menu '%1'" ).arg( txt ), formWindow,
this, (QDesignerPopupMenu*)popup, oldPos, insertAt, txt );
// do not execute, we did the work already
formWindow->commandHistory()->addCommand( cmd );
@@ -1030,7 +1030,7 @@ void QDesignerPopupMenu::createPopupMenu()
return;
RemoveActionFromPopupCommand *cmd = new RemoveActionFromPopupCommand(
i18n("Delete Action '%1' From Popup Menu '%2'" ).
- tqarg( a->name() ).tqarg( caption() ),
+ arg( a->name() ).arg( caption() ),
formWindow, a, this, itm );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -1069,7 +1069,7 @@ void QDesignerPopupMenu::mouseMoveEvent( TQMouseEvent *e )
if ( !a )
return;
RemoveActionFromPopupCommand *cmd = new RemoveActionFromPopupCommand( i18n("Delete Action '%1' From Popup Menu '%2'" ).
- tqarg( a->name() ).tqarg( caption() ),
+ arg( a->name() ).arg( caption() ),
formWindow, a, this, itm );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -1082,7 +1082,7 @@ void QDesignerPopupMenu::mouseMoveEvent( TQMouseEvent *e )
drag->setPixmap( a->iconSet().pixmap() );
if ( !drag->drag() ) {
AddActionToPopupCommand *cmd = new AddActionToPopupCommand( i18n("Add Action '%1' to Popup Menu '%2'" ).
- tqarg( a->name() ).tqarg( name() ),
+ arg( a->name() ).arg( name() ),
formWindow, a, this, itm );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();
@@ -1164,7 +1164,7 @@ void QDesignerPopupMenu::dropEvent( TQDropEvent *e )
}
AddActionToPopupCommand *cmd = new AddActionToPopupCommand( i18n("Add Action '%1' to Popup Menu '%2'" ).
- tqarg( a->name() ).tqarg( name() ),
+ arg( a->name() ).arg( name() ),
formWindow, a, this, insertAt );
formWindow->commandHistory()->addCommand( cmd );
cmd->execute();